@@ -1,21 +1,9 @@
 /* This file is part of the KDE project
-   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
+   SPDX-FileCopyrightText: 2001 Christoph Cullmann <cullmann@kde.org>
+   SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+   SPDX-FileCopyrightText: 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #ifndef KATE_VIEWSPACE_H
@@ -164,9 +152,11 @@ private:
 
     /**
      * all documents this view space is aware of
-     * the all will have tab bar buttons existing
+     * depending on the limit of tabs, not all will have a corresponding
+     * tab in the KateTabBar
+     * these are stored in used order (MRU last)
      */
-    QSet<KTextEditor::Document *> m_registeredDocuments;
+    QVector<KTextEditor::Document *> m_registeredDocuments;
 
     // the list of views that are contained in this view space,
     // mapped through a hash from Document to View.
